@@ -19,9 +19,22 @@
 #---------------------------------------------------------------------------
 
 import os
-import utils
+from core import utils
 
+# paths
+THEMES_FOLDER_PATH = "themes"
+# folder names
 MONAV_DATA_FOLDER_NAME = "monav_data"
+CACHE_FOLDER_NAME = "cache"
+TRACKLOG_FOLDER_NAME = "tracklogs"
+MAPS_FOLDER_NAME = "maps"
+POI_FOLDER_NAME = "poi"
+ROUTING_DATA_FOLDER_NAME = "routing_data"
+DEBUG_LOGS_FOLDER_NAME = "debug_logs"
+# file names
+OPTIONS_FILENAME = "options.bin"
+POI_DB_FILENAME = "modrana_poi.db"
+VERSION_INFO_FILENAME = "version.txt"
 
 class Paths(object):
   """
@@ -59,11 +72,11 @@ class Paths(object):
 
   def getOptionsFilePath(self):
     """return path to the options store filename"""
-    return os.path.join(self.getProfilePath(),"options.bin")
+    return os.path.join(self.getProfilePath(), OPTIONS_FILENAME)
 
   def getCacheFolderPath(self):
     """return path to a folder used for various cache data"""
-    return self._assurePathFolder(self.getProfilePath(), "cache")
+    return self._assurePathFolder(self.getProfilePath(), CACHE_FOLDER_NAME)
 
   def getTracklogsFolderPath(self):
     """return path to a folder for storing tracklogs"""
@@ -79,7 +92,7 @@ class Paths(object):
 
     if path is None: # this means there is no config or device path
       # use default path & assure it exists
-      return self._assurePathFolder(self.getProfilePath(), "tracklogs")
+      return self._assurePathFolder(self.getProfilePath(), TRACKLOG_FOLDER_NAME)
     else:
       return self._assurePath(path)
 
@@ -97,7 +110,7 @@ class Paths(object):
 
     if path is None: # this means there is no config or device path
       # use default path & assure it exists
-      return self._assurePathFolder(self.getProfilePath(), "maps")
+      return self._assurePathFolder(self.getProfilePath(), MAPS_FOLDER_NAME)
     else:
       return self._assurePath(path)
 
@@ -108,13 +121,13 @@ class Paths(object):
       if path is not None: # None means there is no device dependent path
         return self._assurePath(path)
       else:
-        return self._assurePathFolder(self.getProfilePath(), "poi")
+        return self._assurePathFolder(self.getProfilePath(), POI_FOLDER_NAME)
     else:
-      return self._assurePathFolder(self.getProfilePath(), "poi")
+      return self._assurePathFolder(self.getProfilePath(), POI_FOLDER_NAME)
 
   def getPOIDatabasePath(self):
     """return path to the POI database file"""
-    POIDBFilename = self.modrana.get('POIDBFilename', 'modrana_poi.db')
+    POIDBFilename = self.modrana.get('POIDBFilename', POI_DB_FILENAME)
     POIFolderPath = self.getPOIFolderPath()
     return os.path.join(POIFolderPath,POIDBFilename)
 
@@ -125,11 +138,23 @@ class Paths(object):
       if path is not None: # None means there is no device dependent path
         return self._assurePath(path)
       else:
-        return self._assurePathFolder(self.getProfilePath(), "debug_logs")
+        return self._assurePathFolder(self.getProfilePath(), DEBUG_LOGS_FOLDER_NAME)
     else:
-      return self._assurePathFolder(self.getProfilePath(), "debug_logs")
+      return self._assurePathFolder(self.getProfilePath(), DEBUG_LOGS_FOLDER_NAME)
 
 
+  def getThemesFolderPath(self):
+    """Return path to the themes folder"""
+    return THEMES_FOLDER_PATH
+
+  def getRoutingDataFolderPath(self):
+    """Return path to the routing data folder"""
+    path = self.modrana.dmod.getRoutingDataFolderPath()
+    if path is not None:
+      return self._assurePathFolder(path, ROUTING_DATA_FOLDER_NAME)
+    else:
+      return self._assurePath(os.path.join(self.getProfilePath(), ROUTING_DATA_FOLDER_NAME))
+
   ## Monav ##
 
   def getMonavDataPath(self):
@@ -137,7 +162,8 @@ class Paths(object):
     this path can be used both for manipulating the data (add,delete, update) &
     using the data for routing)
     """
-    return self._assurePathFolder(self.getMapFolderPath(), MONAV_DATA_FOLDER_NAME)
+    path = os.path.join(self.getRoutingDataFolderPath(), MONAV_DATA_FOLDER_NAME)
+    return self._assurePath(path)
 
   def getMonavServerBinaryPath(self):
     deviceID = self.modrana.dmod.getDeviceIDString()
@@ -164,7 +190,7 @@ class Paths(object):
     load version string from file
     """
     self.versionString = None
-    versionFilePath = 'version.txt'
+    versionFilePath = VERSION_INFO_FILENAME
     # try read the version file
     if os.path.exists(versionFilePath):
       try:
@@ -174,7 +200,9 @@ class Paths(object):
         # is it really string ?
         versionString = str(versionString)
         self.versionString = versionString
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("modRana config: loading version info failed")
         print(e)
 
