@@ -3,7 +3,15 @@
 from __future__ import with_statement # for python 2.5
 import threading
 import os
-from cStringIO import StringIO
+import sys
+
+from core.backports.six import b
+from core.backports import six
+StringIO = six.moves.cStringIO
+
+PYTHON3 = sys.version_info[0] > 2
+
+
 #import time
 
 class Empty(Exception):
@@ -39,11 +47,9 @@ class SynchronizedCircularStack(object):
   def batchPush(self, itemList):
     """batch push items in a smart way"""
     with self.listLock:
-      """
-      reverse the input list to simulate stack pushes
-      then combine the old list and the new one
-      and finally slice it to fit to the size limit
-      """
+      # reverse the input list to simulate stack pushes
+      # then combine the old list and the new one
+      # and finally slice it to fit to the size limit
       itemList.reverse()
       self.list.extend(itemList)
       self.list = self.list[-self.maxItems:]
@@ -138,23 +144,26 @@ def isTheStringAnImage(s):
   """test if the string contains an image
   by reading its magic number"""
 
-  # create a file-like object
-  f = StringIO(s)
-  # read the header from it
-  h = f.read(32)
-  # cleanup
-  f.close()
+  if PYTHON3: # in Python 3 we directly get bytes
+    h = s
+  else: # in Python <3 we get a string
+    # create a file-like object
+    f = StringIO(s)
+    # read the header from it
+    h = f.read(32)
+    # cleanup
+    f.close()
 
   # NOTE: magic numbers taken from imghdr source code
 
   # as most tiles are PNGs, check for PNG first
-  if h[:8] == "\211PNG\r\n\032\n":
+  if h[:8] == b("\211PNG\r\n\032\n"):
     return True
-  elif h[6:10] in ('JFIF', 'Exif'): # JPEG in JFIF or Exif format
+  elif h[6:10] in (b('JFIF'), b('Exif')): # JPEG in JFIF or Exif format
     return True
-  elif h[:6] in ('GIF87a', 'GIF89a'): # GIF ('87 and '89 variants)
+  elif h[:6] in (b('GIF87a'), b('GIF89a')): # GIF ('87 and '89 variants)
     return True
-  elif h[:2] in ('MM', 'II', 'BM'): # tiff or BMP
+  elif h[:2] in (b('MM'), b('II'), b('BM')): # tiff or BMP
     return True
   else: # probably not an image file
     return False
@@ -182,6 +191,17 @@ def createFolderPath(newPath):
       os.mkdir(newPath)
     return True
 
+#from
+# http://stackoverflow.com/questions/3167154/
+# how-to-split-a-dos-path-into-its-components-in-python
+def SplitPath( split_path ):
+  pathSplit_lst   = []
+  while os.path.basename(split_path):
+      pathSplit_lst.append( os.path.basename(split_path) )
+      split_path = os.path.dirname(split_path)
+  pathSplit_lst.reverse()
+  return pathSplit_lst
+
 # from:
 # http://www.5dollarwhitebox.org/drupal/node/84
 def bytes2PrettyUnitString(bytes):
