@@ -20,9 +20,11 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
 import subprocess
+import time
 from base_device_module import DeviceModule
 #N900 specific:
 import dbus.glib
+
 from core import gs
 # only import GTK, Hildon & Liblocation when using GTK GUI
 if gs.GUIString == "GTK":
@@ -33,18 +35,17 @@ if gs.GUIString == "GTK":
   # therefore, it is important it is loaded only with fort the GTK GUI
   #  import dbus.glib
   import gtk
-
-  """
-  why dbus.glib ?
-  if you import only "dbus", it can't find its mainloop for callbacks
-  """
+  # why dbus.glib ?
+  # if you import only "dbus", it can't find its mainloop for callbacks
 elif gs.GUIString == "QML":
   from QtMobility.SystemInfo import QSystemScreenSaver
+  # ^^ back-light control for QML GUI
 
-  """ ^^ back-light control"""
-
-import time
-
+TRACKLOGS_PATH = "/home/user/MyDocs/tracklogs"
+MAP_FOLDER_PATH = "/home/user/MyDocs/.maps/"
+POI_FOLDER_PATH = "/home/user/MyDocs/.maps"
+ROUTING_DATA_FOLDER_PATH = "/home/user/MyDocs/.maps"
+DEBUG_LOG_FOLDER_PATH = "/home/user/MyDocs/modrana_debug_logs/"
 
 def getModule(m, d, i):
   return DeviceN900(m, d, i)
@@ -124,12 +125,10 @@ class DeviceN900(DeviceModule):
 
       # window-active detection
       self.topWindow.connect('notify::is-active', self.windowIsActiveChangedCallback)
-      """
-      on the Maemo 5@N900, is-active == True signalizes that the modRana window is
-      the current active window (there is always only one active window)
-      is-active == False signalizes that the window is either minimized on the
-      dashboard or the screen is blanked
-      """
+      # on Maemo 5@N900, is-active == True signalizes that the modRana window is
+      # the current active window (there is always only one active window)
+      # is-active == False signalizes that the window is either minimized on the
+      # dashboard or the screen is blanked
       # enable volume keys usage
       if self.get('useVolumeKeys', True):
         self._updateVolumeKeys()
@@ -145,7 +144,7 @@ class DeviceN900(DeviceModule):
   def fullscreenOnly(self):
     return False
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     if message == 'modeChanged':
       rotationMode = self.get('rotationMode', None)
       if rotationMode:
@@ -180,7 +179,9 @@ class DeviceN900(DeviceModule):
                                                        mode=lastModeNumber)
       print("N900 rotation object initialized")
       return rObject
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("initializing N900 rotation object failed")
       print(e)
 
@@ -222,13 +223,11 @@ class DeviceN900(DeviceModule):
     - no focus -> the window is switched to dashboard or the another window is active or
     the screen is blanked"""
     redrawOnDashboard = self.get('redrawOnDashboard', False)
-    """
-    NOTE: this updates the snapshot in task switcher,
-    but also UPDATES WHEN MINIMISED AND NOT VISIBLE
-    so use with caution
-    blanking overrides this so when the screen is blanked it does not redraw
-    TODO: see if hildon signalizes that a the task switcher is visible or not
-    """
+    # NOTE: this updates the snapshot in task switcher,
+    # but also UPDATES WHEN MINIMISED AND NOT VISIBLE
+    # so use with caution
+    # blanking overrides this so when the screen is blanked it does not redraw
+    # TODO: see if hildon signalizes that a the task switcher is visible or not
 
     if not redrawOnDashboard: # we don't redraw on dashboard by default
       display = self.m.get('display', None)
@@ -387,16 +386,20 @@ class DeviceN900(DeviceModule):
   # ** PATHS **
 
   def getTracklogFolderPath(self):
-    return "/home/user/MyDocs/tracklogs"
+    return TRACKLOGS_PATH
 
   def getMapFolderPath(self):
-    return "/home/user/MyDocs/.maps/"
+    return MAP_FOLDER_PATH
 
   def getPOIFolderPath(self):
-    return "/home/user/MyDocs/.maps"
+    return POI_FOLDER_PATH
 
   def getLogFolderPath(self):
-    return "/home/user/MyDocs/modrana_debug_logs/" #N900 specific log folder
+    # N900 specific log folder
+    return DEBUG_LOG_FOLDER_PATH
+
+  def getRoutingDataFolderPath(self):
+    return ROUTING_DATA_FOLDER_PATH
 
   # ** LOCATION **
 
@@ -445,23 +448,31 @@ class DeviceN900(DeviceModule):
           import location
         self.lControl = location.GPSDControl.get_default()
         self.lDevice = location.GPSDevice()
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("n900 - location: - cant create location objects: %s" % e)
 
       try:
         self.lControl.set_properties(preferred_method=location.METHOD_USER_SELECTED)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("n900 - location: - cant set preferred location method: %s" % e)
 
       try:
         self.lControl.set_properties(preferred_interval=location.INTERVAL_1S)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("n900 - location: - cant set preferred location interval: %s" % e)
       try:
         self.lControl.start()
         print("** n900 - location: - GPS successfully activated **")
         self.connected = True
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("n900 - location: - opening the GPS device failed: %s" % e)
         self.status = "No GPSD running"
 
@@ -469,7 +480,9 @@ class DeviceN900(DeviceModule):
       #self.lControl.connect("error-verbose", self._liblocationErrorCB)
       self.lDevice.connect("changed", self._libLocationUpdateCB)
       print("n900 - location: activated")
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       self.status = "No GPSD running"
       print("n900 - location: - importing location module failed, please install the python-location package")
       print(e)
@@ -527,13 +540,11 @@ class DeviceN900(DeviceModule):
 
         fix = device.fix
         self.set('fix', fix[0])
-        """from liblocation reference:
-        0 =	The device has not seen a satellite yet.
-        1 =	The device has no fix.
-        2 =	The device has latitude and longitude fix.
-        3 =	The device has latitude, longitude, and altitude.
-        """
-
+        # from liblocation reference:
+        # 0 =	The device has not seen a satellite yet.
+        # 1 =	The device has no fix.
+        # 2 =	The device has latitude and longitude fix.
+        # 3 =	The device has latitude, longitude, and altitude.
         if fix[1] & location.GPS_DEVICE_LATLONG_SET:
           (lat, lon) = fix[4:6]
           self.set('pos', (lat, lon))
@@ -551,7 +562,6 @@ class DeviceN900(DeviceModule):
           elev = fix[7]
           self.set('elevation', elev)
 
-        # TODO: remove when not needed
         if self.get('n900GPSDebug', False):
           print("## N900 GPS debugging info ##")
           print("fix tuple from the Location API:")
@@ -570,7 +580,9 @@ class DeviceN900(DeviceModule):
       else:
         self.status = "Unknown"
         print("n900 - location: getting fix failed (on a regular update)")
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       self.status = "Unknown"
       print("n900 - location:getting fix failed (on a regular update + exception: %s)" % e)
 
