@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A Neo FreeRunner modRana device-specific module.
@@ -20,17 +19,36 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_device_module import deviceModule
+from base_device_module import DeviceModule
+import subprocess
 
-def getModule(m,d,i):
-  return(device_neo(m,d,i))
 
-class device_neo(deviceModule):
+def getModule(m, d, i):
+  return DeviceNeo(m, d, i)
+
+
+class DeviceNeo(DeviceModule):
   """A Neo FreeRunner modRana device-specific module"""
-  
+
   def __init__(self, m, d, i):
-    deviceModule.__init__(self, m, d, i)
+    DeviceModule.__init__(self, m, d, i)
     self.tempUnfullscreen = False
+    # connect to the location start & stop signals,
+    # so that the FreeRunners GPS can be started/stopped
+    l = self.m.get('location', None)
+    if l is not None:
+      l.startSignal.connect(self._startLocationCB)
+      l.stopSignal.connect(self._stopLocationCB)
+
+
+  def _startLocationCB(self):
+    """start the GPS hardware"""
+    print("HANDLE GPS STARTUP")
+
+  def _stopLocationCB(self):
+    """stop the GPS hardware"""
+    print("HANDLE GPS SHUTDOWN")
+
 
   def getDeviceIDString(self):
     return "neo"
@@ -39,7 +57,7 @@ class device_neo(deviceModule):
     return "OpenMoko Neo FreeRunner"
 
   def getWinWH(self):
-    return (480,600)
+    return 480, 600
 
   def startInFullscreen(self):
     return True
@@ -75,8 +93,7 @@ class device_neo(deviceModule):
           display.fullscreenToggle()
           self.tempUnfullscreen = False
 
-if(__name__ == "__main__"):
-  a = device_example({}, {})
-  a.update()
-  a.update()
-  a.update()
+  def getLocationType(self):
+    """we use GPSD for location on the Neo FreeRunner
+    as it should be available on both the DH & QtMoko"""
+    return "gpsd"
