@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A PC modRana device-specific module.
@@ -20,16 +19,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_device_module import deviceModule
+from base_device_module import DeviceModule
 
 def getModule(m,d,i):
-  return(Device_PC(m,d,i))
+  return DevicePC(m,d,i)
 
-class Device_PC(deviceModule):
+class DevicePC(DeviceModule):
   """A modRana device-specific module for PC"""
   
   def __init__(self, m, d, i):
-    deviceModule.__init__(self, m, d, i)
+    DeviceModule.__init__(self, m, d, i)
 
   def getDeviceIDString(self):
     return "pc"
@@ -38,7 +37,7 @@ class Device_PC(deviceModule):
     return "A generic Personal Computer"
 
   def getWinWH(self):
-    return (800,480)
+    return 800,480
 
   def simpleMapDragging(self):
     return False
@@ -47,11 +46,4 @@ class Device_PC(deviceModule):
     return False
 
   def getSupportedGUIModuleIds(self):
-    return ["GTK", "QML"]
-
-
-if(__name__ == "__main__"):
-  a = device_example({}, {})
-  a.update()
-  a.update()
-  a.update()
+    return ["GTK", "QML:indep"]
