@@ -27,7 +27,7 @@ class PieChart (QDeclarativeItem):
 
   def __init__(self, parent = None):
     QDeclarativeItem.__init__(self, parent)
-    self._name = u''
+    self._name = ''
     self._pieSlice = None
 
   def getName(self):
@@ -36,7 +36,7 @@ class PieChart (QDeclarativeItem):
   def setName(self, value):
     self._name = value
 
-  name = Property(unicode, getName, setName)
+  name = Property(str, getName, setName)
 
   def getPieSlice(self):
     return self._pieSlice
