@@ -21,11 +21,13 @@ from modules.base_module import RanaModule
 import os
 import glob
 import fnmatch
-"""for some reason one import method works
-on Fremantle and other everywhere (?) else"""
+# for some reason one import method works
+# on Fremantle and other everywhere (?) else"""
 try:
   from modules.configobj.configobj import ConfigObj # everywhere
-except Exception, e:
+except Exception:
+  import sys
+  e = sys.exc_info()[1]
   print(e)
   print("icons: trying alternative configobj import method")
   from configobj import ConfigObj # Fremantle
@@ -37,6 +39,7 @@ if gs.GUIString == "GTK":
   import gtk
   import cairo
   from core.color import Color
+from core import constants
 
 def getModule(m,d,i):
   return Icons(m,d,i)
@@ -46,8 +49,7 @@ class Icons(RanaModule):
   def __init__(self, m, d, i):
     RanaModule.__init__(self, m, d, i)
 
-    self.defaultTheme = 'default'
-    self.themesFolderPath = 'themes/'
+    self.defaultTheme = constants.DEFAULT_THEME_ID
     self.cantLoad = []
     self.imageOrderList = [] # for cache trimming
     self.maxImages = 200 # default 200
@@ -59,8 +61,11 @@ class Icons(RanaModule):
     # structure -> color_key:color_object
     self.defaultColors = {} # default color set
     self.colors = {} # main combined color set
-    defaultThemeConfig = os.path.join(self.themesFolderPath, self.defaultTheme, 'theme.conf')
-    self.updateThemeList()
+    defaultThemeConfig = os.path.join(
+      self.modrana.paths.getThemesFolderPath(),
+      self.defaultTheme,
+      'theme.conf'
+    )
     # TODO: make themes GUI toolkit independent
     if gs.GUIString == "GTK":
       # load the default set of colors
@@ -94,7 +99,7 @@ class Icons(RanaModule):
     iconPathDefault = self.getDefaultThemePath()
     simplePaths = None
     for path in (iconPathThemed, iconPathDefault):
-      simplePaths = glob.glob(path+"%s.*" % name)
+      simplePaths = glob.glob(os.path.join(path, "%s.*" % name))
       if simplePaths:
         break
     if simplePaths:
@@ -156,8 +161,8 @@ class Icons(RanaModule):
         border = min(w,h)*0.1
         targetH = (h*0.55)
         targetW = w - 2*border
-        """ try to fit the icon image above the text inside the icon outline,
-            with some space between, while respecting original aspect ratio"""
+        # try to fit the icon image above the text inside the icon outline,
+        # with some space between, while respecting original aspect ratio"""
         scaledW = targetW
         scaledH = targetW/float(hwRatio)
         if scaledH > targetH:
@@ -169,7 +174,9 @@ class Icons(RanaModule):
         try:
           # try to load the icon to pixbuf and get its original width and height
           pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(aboveTextIconPath,int(scaledW),int(scaledH))
-        except Exception, e:
+        except Exception:
+          import sys
+          e = sys.exc_info()[1]
           print("icons: icon probably corrupted: %s" % aboveTextIconPath)
           print("%s" % e)
         if pixbuf:
@@ -208,26 +215,26 @@ class Icons(RanaModule):
        then return the image surface"""
     try:
       pixbuf = gtk.gdk.pixbuf_new_from_file(path)
-      """
-      if width or height are not set, we take them from the pixbuf
-      if both are not set, we disable scaling
-      """
+      #if width or height are not set, we take them from the pixbuf
+      #if both are not set, we disable scaling
 
       (w,h,scale) = self._getValidParams(w, h, pixbuf)
 
-      ''' create a new cairo surface to place the image on '''
+      # create a new cairo surface to place the image on
       image = cairo.ImageSurface(0,w,h)
-      ''' create a context to the new surface '''
+      # create a context to the new surface
       ct = cairo.Context(image)
-      ''' create a GDK formatted Cairo context to the new Cairo native context '''
+      # create a GDK formatted Cairo context to the new Cairo native context
       ct2 = gtk.gdk.CairoContext(ct)
-      ''' draw from the pixbuf to the new surface '''
+      # draw from the pixbuf to the new surface
       if scale:
         pixbuf = pixbuf.scale_simple(w,h,gtk.gdk.INTERP_HYPER)
       ct2.set_source_pixbuf(pixbuf,0,0)
       ct2.paint()
-      ''' surface now contains the image in a Cairo surface '''
-    except Exception, e:
+      # surface now contains the image in a Cairo surface
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("** loading image to pixbuf failed")
       print("** filename: %s" % path)
       print("** exception: %s" % e)
@@ -315,7 +322,9 @@ class Icons(RanaModule):
     try:
       (r,g,b,a) = fillColorRGBATuple
       fillColorRGBATuple = (r,g,b,fillAlpha)
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("** wrong fill color code or name: %s" % fillColorString)
       print("** exception: %s" % e)
       fillColorRGBATuple = self.buttonFillColor
@@ -323,7 +332,9 @@ class Icons(RanaModule):
     try:
       (r,g,b,a) = outlineColorRGBATuple
       outlineColorRGBATuple = (r,g,b,outlineAlpha)
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("** wrong outline color code or name: %s" % fillColorString)
       print("** exception: %s" % e)
       outlineColorRGBATuple = self.buttonOutlineColor
@@ -346,8 +357,8 @@ class Icons(RanaModule):
     parameterPaths = None
     # list the theme directory
     for path in themePathList:
-      simplePaths = glob.glob(path+"%s.*" % name)
-      parameterPaths = glob.glob(path+"%s-*.*" % name)
+      simplePaths = glob.glob(os.path.join(path,"%s.*") % name)
+      parameterPaths = glob.glob(os.path.join(path,"%s-*.*" % name))
       if parameterPaths or simplePaths:
         break
     return simplePaths, parameterPaths
@@ -368,12 +379,11 @@ class Icons(RanaModule):
       # run through possible "layers", which are separated by >
       compositedIcon = None
       needBackground = False
-      """icon specifications are separated by >,
-      which should be seen as a pointing arrow in this context
-      we composite top -> down,
-      for example: "icon1>icon2"
-      icon1 will be drawn over icon2
-      """
+      # icon specifications are separated by >,
+      # which should be seen as a pointing arrow in this context
+      # we composite top -> down,
+      # for example: "icon1>icon2"
+      # icon1 will be drawn over icon2
       for currentName in reversed(name.split('>')): # we draw top down
 
         if currentName.split(':')[0] == 'generic':
@@ -385,19 +395,17 @@ class Icons(RanaModule):
           else:
             # the icon name contains custom positional parameters
             semicolonSepList = currentName.split(':',1)[1].split(';')
-            """
-            there are five positional parameters:
-            fill color,fill opacity, outline color, outline opacity,
-            outline width (default 8) and corner radius (default 22)
-            to use default value, just don't fill in the positional parameter
-            ( len(parameter) == 0
-            """
+            # there are five positional parameters:
+            # fill color,fill opacity, outline color, outline opacity,
+            # outline width (default 8) and corner radius (default 22)
+            # to use default value, just don't fill in the positional parameter
+            # ( len(parameter) == 0
             needBackground = False
             parametricIcon = self.getCustomIcon(semicolonSepList,w,h)
             compositedIcon = self.combineTwoIcons(compositedIcon, parametricIcon)
         elif currentName.split(':')[0] == 'above':
-          """ "above" means that we have an icon that we want to position above any text that
-          can be on the button"""
+          # "above" means that we have an icon that we want to position above any text that
+          # can be on the button
           loadingResult = self.loadFromFile(currentName.split(':')[1], w, h)
           if loadingResult == False:
             self.cantLoad.append(currentName)
@@ -407,13 +415,13 @@ class Icons(RanaModule):
             compositedIcon = self.combineTwoIcons(compositedIcon, loadingResult)
 
         elif currentName.split(':')[0] == 'center':
-          """ "center" means that we have an icon which we want to center inside the button
-          there re two parameters - icon name and border width
-          EXAMPLE: center:more;0.1;0.5
-          -> icon name: more
-          -> border width: 10% of shortest icon side
-          -> 50% opacity
-          """
+          # "center" means that we have an icon which we want to center inside the button
+          # there re two parameters - icon name and border width
+          # EXAMPLE: center:more;0.1;0.5
+          # -> icon name: more
+          # -> border width: 10% of shortest icon side
+          # -> 50% opacity
+
           # parse the parameters
           semicolonSepList = currentName.split(':',1)[1].split(';')
           iconName = semicolonSepList[0]
@@ -471,8 +479,8 @@ class Icons(RanaModule):
                   newW = iw*(newH/ih)
 
               # shift to center
-              dx = border+(uw - newW)/2.0
-              dy = border+(uh - newH)/2.0
+              dx = border + (uw - newW)/2.0
+              dy = border + (uh - newH)/2.0
               
               # crete contexts
               ct = cairo.Context(background)
@@ -539,7 +547,7 @@ class Icons(RanaModule):
     self.imageOrderList.append(name)
     return cacheRepresentation
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     if message == "themeChanged":
       # handle theme switching
       currentTheme = self.get('currentTheme', self.defaultTheme)
@@ -593,21 +601,13 @@ class Icons(RanaModule):
     cr.stroke()
     return image
 
-  def updateThemeList(self):
-    rawFolderContent = os.listdir(self.themesFolderPath)
-    self.availableThemes = filter(lambda x: os.path.isdir(os.path.join(self.themesFolderPath, x)) and not x=='.svn',rawFolderContent)
-
-  def getThemeList(self):
-    """return a a list of currently available themes (list of folders in the themes folder)"""
-    return self.availableThemes
-
   def getCurrentThemePath(self):
     """returns path to currently active theme"""
-    return self.themesFolderPath + '/' + self.currentTheme + '/'
+    return os.path.join(self.modrana.paths.getThemesFolderPath(), self.currentTheme)
 
   def getDefaultThemePath(self):
     """returns path to currently active theme"""
-    return self.themesFolderPath + '/' + self.defaultTheme + '/'
+    return os.path.join(self.modrana.paths.getThemesFolderPath(), self.defaultTheme)
 
   def switchTheme(self, newTheme):
     """switch the current theme to another one"""
