@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
-# Sample of a modRana module.
+# A modRana module for map layer handling
 #----------------------------------------------------------------------------
-# Copyright 2007, Oliver White
+# Copyright 2013, Martin Kolman
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #---------------------------------------------------------------------------
 from modules.base_module import RanaModule
 from core.signal import Signal
+from core.backports import six
 
 # lists keys that need to be defined for a layer
 # in the map configuration file to be valid,
@@ -48,7 +49,7 @@ def getModule(m,d,i):
   return MapLayers(m,d,i)
 
 class MapLayers(RanaModule):
-  """A sample modRana module"""
+  """Map layer handling"""
   
   def __init__(self, m, d, i):
     RanaModule.__init__(self, m, d, i)
@@ -135,7 +136,7 @@ class MapLayers(RanaModule):
     # check if there is at least one valid layer
 
     layerDefinitions = self.modrana.configs.mapConfig.get('layers', {})
-    for layerId, layerDefinition in layerDefinitions.iteritems():
+    for layerId, layerDefinition in six.iteritems(layerDefinitions):
       if self._hasRequiredKeys(layerDefinition, MAP_LAYER_REQUIRED_KEYS):
         self._layers[layerId] = MapLayer(layerId, layerDefinition)
       else:
@@ -152,7 +153,7 @@ class MapLayers(RanaModule):
     # configuration file has any
     if self.modrana.configs.mapConfig:
       groupsDict = self.modrana.configs.mapConfig.get('groups', {})
-      for groupId, groupDefinition in groupsDict.iteritems():
+      for groupId, groupDefinition in six.iteritems(groupsDict):
         if self._hasRequiredKeys(groupDefinition, MAP_LAYER_GROUP_REQUIRED_KEYS):
           self._groups[groupId] = MapLayerGroup(self, groupId, groupDefinition)
 
@@ -256,7 +257,7 @@ class MapLayerGroup(object):
     self._layers = self._mapLayers.getLayersByGroupId(self.id)
     # sort the layers by the label
     # as that is what is usually needed when displaying them
-    self._layers.sort(key=lambda l: l.label)
+    self._layers = sorted(self._layers, key=lambda l: l.label)
 
   @property
   def id(self):
