@@ -39,7 +39,7 @@ class Notification(RanaModule):
     self.workInProgressOverlayText = ""
     """this indicates if the notification about background processing should be shown"""
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     """the first part is the message, that will be displayed,
        there can also by some parameters, delimited by #
        NEW: you can also use a message list for the notification
@@ -49,8 +49,8 @@ class Notification(RanaModule):
        EXAMPLE: ml:notification:m:Hello world!;5
        """
 
-    if type=='ml' and message=='m':
-      """advanced message list based notification"""
+    if messageType=='ml' and message=='m':
+      # advanced message list based notification
       if args:
         timeout = self.timeout
         if len(args) >= 2:
@@ -58,7 +58,7 @@ class Notification(RanaModule):
         messageText = args[0]
         self.handleNotification(messageText, timeout)
 
-    elif type=='ml' and message=='workInProgressOverlay':
+    elif messageType=='ml' and message=='workInProgressOverlay':
       if args:
         if args[0] == "enable":
           self.startWorkInProgressOverlay()
@@ -66,15 +66,17 @@ class Notification(RanaModule):
           self.stopWorkInProgressOverlay()
           
     else:
-      list = message.split('#')
-      if len(list) >= 2:
-        messageText = list[0]
+      parameterList = message.split('#')
+      if len(parameterList) >= 2:
+        messageText = parameterList[0]
         timeout = self.timeout
         self.handleNotification(messageText, timeout)
-        if len(list) == 2:
+        if len(parameterList) == 2:
           try:
-            timeout = int(list[1]) # override the default timeout
-          except Exception ,e:
+            timeout = int(parameterList[1]) # override the default timeout
+          except Exception:
+            import sys
+            e = sys.exc_info()[1]
             print("notification: wrong timeout, using default 5 seconds")
             print(e)
         self.handleNotification(messageText, timeout)
@@ -94,8 +96,8 @@ class Notification(RanaModule):
     
   def setWorkInProgressOverlayText(self, text):
     self.workInProgressOverlayText = text
-    """ if the overlay is enabled, 
-    trigger screen redraw if the text changes"""
+    # if the overlay is enabled,
+    # trigger screen redraw if the text changes
     if self.workInProgressOverlay:
       self.set('needRedraw', True)
 
@@ -150,8 +152,8 @@ class Notification(RanaModule):
         dy = dx
         x1 = (x+w)-dx
         y1 = y
-      """ the cancel button sends a cancel message to onlineServices
-      to disable currently running operation"""
+      # the cancel button sends a cancel message to onlineServices
+      # to disable currently running operation
       menus.drawButton(cr, x1, y1, dx, dy, '#<span foreground="red">cancel</span>', "generic:;0.5;;0.5;;", '')
       click.registerXYWH(x1, y1, dx, dy, "onlineServices:cancelOperation", layer=2)
 
