@@ -181,7 +181,7 @@ class GoogleMaps(object):
   """
 
   _GEOCODE_QUERY_URL = 'http://maps.google.com/maps/geo?'
-  _DIRECTIONS_QUERY_URL = 'http://maps.google.com/maps/nav?'
+  _DIRECTIONS_QUERY_URL = 'http://maps.googleapis.com/maps/api/directions/json?'
   _LOCAL_QUERY_URL = 'http://ajax.googleapis.com/ajax/services/search/local?'
   _LOCAL_RESULTS_PER_PAGE = 8
   MAX_LOCAL_RESULTS = 32
@@ -359,7 +359,7 @@ class GoogleMaps(object):
     Sushi Groove
     >>> print result['streetAddress']
     1916 Hyde St
-    >>> print result['phoneNumbers'][0]['number']
+    >>> print(result['phoneNumbers'][0]['number'])
     (415) 440-1905
 
     For more information on the available data, see Google's documentation on
@@ -436,8 +436,8 @@ class GoogleMaps(object):
     >>> dist  = dirs['Directions']['Distance']['meters']
     >>> route = dirs['Directions']['Routes'][0]
     >>> for step in route['Steps']:
-    ...    print step['Point']['coordinates'][1], step['Point']['coordinates'][0]
-    ...    print step['descriptionHtml']
+    ...    print(step['Point']['coordinates'][1], step['Point']['coordinates'][0])
+    ...    print(step['descriptionHtml'])
     38.8921 -77.02604
     Head <b>east</b> on <b>Constitution Ave NW</b> toward <b>9th St NW</b>
     38.89208 -77.02191
@@ -457,17 +457,20 @@ class GoogleMaps(object):
 
     """
     params = {
-      'q': 'from:%s to:%s' % (origin, destination),
+      'origin' : origin,
+      'destination' : destination,
       'output': 'js', #modRana:NOTE:modified to js to get polyline data
       'oe': 'utf8',
-      'key': self.api_key,
+#      'key': self.api_key, # TODO: API key
     }
     params.update(kwargs)
     params.update(dir) #modRana: add mode parameter
-
     url, response = fetch_json(self._DIRECTIONS_QUERY_URL, params=params)
-    status_code = response['Status']['code']
-    if status_code != STATUS_OK:
+    status_code = response['status']
+#    if status_code != STATUS_OK:
+    if status_code != "OK":
+      # TODO: update status codes for directions
+      #(https://developers.google.com/maps/documentation/directions/#StatusCodes)
       raise GoogleMapsError(status_code, url=url, response=response)
     return response
 
@@ -489,7 +492,7 @@ if __name__ == "__main__":
     """
 
     if len(argv) < 2 or len(argv) > 4:
-      print main.__doc__
+      print(main.__doc__)
       sys.exit(1)
 
     query = argv[1]
