@@ -23,9 +23,9 @@ import sys
 import re
 import threading
 import time
-import geocoding
-import geonames
-import local_search
+from . import geocoding
+from . import geonames
+from . import local_search
 
 DEFAULT_GOOGLE_API_KEY = "ABQIAAAAv84YYgTIjdezewgb8xl5_xTKlax5G-CAZlpGqFgXfh-jq3S0yRS6XLrXE9CkHPS6KDCig4gHvHK3lw"
 
@@ -46,7 +46,7 @@ class OnlineServices(RanaModule):
   #  def firstTime(self):
   #    self._enableOverlay()
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     if message == "cancelOperation":
       """this message is sent when the user presses the "cancel search" button
          it should:
@@ -259,7 +259,8 @@ class OnlineServices(RanaModule):
 
     try:
       directions = gMap.directions(start, destination, dir)
-    except googlemaps.GoogleMapsError, e:
+    except googlemaps.GoogleMapsError:
+      e = sys.exc_info()[1]
       if e.status == 602:
         print("onlineServices:GDirections:routing failed -> address not found" % e)
         self.sendMessage("ml:notification:m:Address(es) not found;5")
@@ -274,7 +275,9 @@ class OnlineServices(RanaModule):
                                                waypointOption=waypointOption, secondTime=True)
       else:
         print("onlineServices:GDirections:routing failed with exception googlemaps status code:%d" % e.status)
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("onlineServices:GDirections:routing failed with non-googlemaps exception")
       print(e)
       traceback.print_exc(file=sys.stdout) # find what went wrong
@@ -548,7 +551,9 @@ class Worker(threading.Thread):
       results = geonames.elevBatchSRTM(latLonList, self._geonamesCallback, userAgent)
       self._setWorkStatusText("online elevation lookup done   ")
       return results, tracklog
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print('onlineServices: exception during elevation lookup')
       print(e)
       traceback.print_exc(file=sys.stdout) # find what went wrong
