@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Draw position marker.
@@ -18,25 +17,20 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 import math
 from math import radians
-from time import clock
-#from tilenames import *
-from core import gs
 
-if gs.GUIString == "GTK":
-  import gtk
-  import cairo
 
-def getModule(m,d,i):
-  return(positionMarker(m,d,i))
+def getModule(m, d, i):
+  return PositionMarker(m, d, i)
 
-class positionMarker(ranaModule):
+
+class PositionMarker(RanaModule):
   """A sample pyroute module"""
-  
+
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
 
   def drawMapOverlay(self, cr):
     """Draw an "own position" marker"""
@@ -45,7 +39,7 @@ class positionMarker(ranaModule):
     pos = self.get('pos', None)
     if pos is None:
       return
-    (lat,lon) = pos
+    (lat, lon) = pos
 
     # Where is the map?
     proj = self.m.get('projection', None)
@@ -55,7 +49,7 @@ class positionMarker(ranaModule):
       return
 
     # Where are we on the map?
-    x1,y1 = proj.ll2xy(lat,lon)
+    x1, y1 = proj.ll2xy(lat, lon)
 
     # What are we?
     angle = self.get('bearing', 0)
@@ -67,16 +61,15 @@ class positionMarker(ranaModule):
       self.drawStandingCircle(cr, x1, y1) # draw TangoGPS style marker without bearing
     else:
       self.drawMovingCircle(cr, x1, y1, angle) # draw TangoGPS style marker with bearing
-#     Draw yellow/black triangle showing us
-#      self.drawArrow(cr, x1, y1, angle)
+      #     Draw yellow/black triangle showing us
+      #      self.drawArrow(cr, x1, y1, angle)
 
 
   def drawMovingCircle(self, cr, x1, y1, angle):
-
     cr.save()
 
     # rotate the marker according to our bearing
-    cr.translate(x1,y1) # we move the coordinates center to where we want the center of the marker
+    cr.translate(x1, y1) # we move the coordinates center to where we want the center of the marker
     cr.rotate(radians(angle))
 
     # circle
@@ -99,11 +92,11 @@ class positionMarker(ranaModule):
     cr.set_source_rgb(0.0, 0.0, 0.0)
     cr.set_line_width(6)
     cr.arc(0, 0, 6, 0, 2.0 * math.pi) # we want round ends :)
-    cr.arc(0, 0-lineLength, 6, 0, 2.0 * math.pi)
+    cr.arc(0, 0 - lineLength, 6, 0, 2.0 * math.pi)
     cr.fill()
     cr.set_line_width(12)
-    cr.move_to(0,0)
-    cr.line_to(0, 0-lineLength)
+    cr.move_to(0, 0)
+    cr.line_to(0, 0 - lineLength)
     cr.stroke()
 
     cr.fill()
@@ -112,22 +105,21 @@ class positionMarker(ranaModule):
     cr.set_source_rgb(1.0, 1.0, 0.0)
     cr.set_line_width(3)
     cr.arc(0, 0, 3, 0, 2.0 * math.pi)
-    cr.arc(0, 0-lineLength, 3, 0, 2.0 * math.pi)
+    cr.arc(0, 0 - lineLength, 3, 0, 2.0 * math.pi)
     cr.fill()
     cr.set_line_width(6)
-    cr.move_to(0,0)
-    cr.line_to(0, 0-lineLength)
+    cr.move_to(0, 0)
+    cr.line_to(0, 0 - lineLength)
     cr.stroke()
     cr.fill()
 
     cr.restore()
 
   def drawStandingCircle(self, cr, x1, y1):
-
     cr.save()
 
     # rotate the marker according to our bearing
-    cr.translate(x1,y1) # we move the coordinates center to where we want the center of the marker
+    cr.translate(x1, y1) # we move the coordinates center to where we want the center of the marker
 
     # circle
 
@@ -156,31 +148,22 @@ class positionMarker(ranaModule):
 
     cr.fill()
 
-
-
     cr.restore()
 
   def drawArrow(self, cr, x1, y1, angle):
     cr.set_source_rgb(1.0, 1.0, 0.0)
     cr.save()
-    cr.translate(x1,y1)
+    cr.translate(x1, y1)
     cr.rotate(radians(angle))
     cr.move_to(-10, 15)
-    cr.line_to( 10, 15)
-    cr.line_to(  0, -15)
+    cr.line_to(10, 15)
+    cr.line_to(0, -15)
     cr.fill()
     cr.set_source_rgb(0.0, 0.0, 0.0)
     cr.set_line_width(3)
     cr.move_to(-10, 15)
-    cr.line_to( 10, 15)
-    cr.line_to(  0, -15)
+    cr.line_to(10, 15)
+    cr.line_to(0, -15)
     cr.close_path()
     cr.stroke()
     cr.restore()
-
-
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
