@@ -28,6 +28,7 @@ import traceback
 import unicodedata
 import core.way as way
 import core.geo as geo
+from core.backports.six import u
 #from time import clock
 import time
 
@@ -65,13 +66,13 @@ class Route(RanaModule):
     self.set('startPos', None)
     self.set('endPos', None)
 
-    file = open(DIRECTIONS_FILTER_CSV_PATH, 'rb')
+    file = open(DIRECTIONS_FILTER_CSV_PATH, 'r')
     CSVReader = csv.reader(file, delimiter=';', quotechar='|') #use an iterator
     self.directionsFilterRules = []
     for row in CSVReader:
       if row[0] != '#' and len(row) >= 2:
-        regex = re.compile(unicode(row[0].decode("utf-8")))
-        self.directionsFilterRules.append((regex, row[1].decode("utf-8")))
+        regex = re.compile(u(row[0]))
+        self.directionsFilterRules.append((regex, u(row[1])))
     file.close()
 
   def _goToInitialState(self):
@@ -106,7 +107,7 @@ class Route(RanaModule):
     self.monav = None
     self.monavDataFolder = None
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     if message == "clear":
       self._goToInitialState()
       self.set('startPos', None)
@@ -127,9 +128,8 @@ class Route(RanaModule):
       if proj and self.expectStart:
         lastClick = self.get('lastClickXY', None)
         (x, y) = lastClick
-        """
-        x and y must be floats, otherwise strange rounding errors occur, when converting to lat lon coordinates
-        """
+        # x and y must be floats, otherwise strange rounding errors
+        # occur when converting to lat lon coordinates
         (lat, lon) = proj.xy2ll(x, y)
         self.set('startPos', (lat, lon))
         self.start = (lat, lon)
@@ -147,9 +147,8 @@ class Route(RanaModule):
       if proj and self.expectMiddle:
         lastClick = self.get('lastClickXY', None)
         (x, y) = lastClick
-        """
-        x and y must be floats, otherwise strange rounding errors occur, when converting to lat lon coordinates
-        """
+        # x and y must be floats, otherwise strange rounding errors
+        # occur when converting to lat lon coordinates
         (lat, lon) = proj.xy2ll(x, y)
         middlePos=self.get('middlePos', [])
         middlePos.append((lat,lon,None, ""))
@@ -172,9 +171,8 @@ class Route(RanaModule):
       if proj and self.expectEnd:
         lastClick = self.get('lastClickXY', None)
         (x, y) = lastClick
-        """
-        x and y must be floats, otherwise strange rounding errors occur, when converting to lat lon coordinates
-        """
+        # x and y must be floats, otherwise strange rounding errors
+        # occur when converting to lat lon coordinates
         (lat, lon) = proj.xy2ll(x, y)
         self.set('endPos', (lat, lon))
         self.destination = (lat, lon)
@@ -277,15 +275,15 @@ class Route(RanaModule):
       self.set('needRedraw', True) # show the new route
 
     elif message == "route": # find a route
-      if type == 'md': # message-list based unpack requires a string argument of length 4 routing
+      if messageType == 'md': # message-list based unpack requires a string argument of length 4 routing
         if args:
-          type = args['type']
+          messageType = args['type']
           go = False
-          if type == 'll2ll':
+          if messageType == 'll2ll':
             (fromLat, fromLon) = (float(args['fromLat']), float(args['fromLon']))
             (toLat, toLon) = (float(args['toLat']), float(args['toLon']))
             go = True
-          elif type == 'pos2ll':
+          elif messageType == 'pos2ll':
             pos = self.get('pos', None)
             if pos:
               (fromLat, fromLon) = pos
@@ -296,13 +294,15 @@ class Route(RanaModule):
             print("Routing %f,%f to %f,%f" % (fromLat, fromLon, toLat, toLon))
             try:
               self.doRoute(fromLat, fromLon, toLat, toLon)
-            except Exception, e:
+            except Exception:
+              import sys
+              e = sys.exc_info()[1]
               self.sendMessage('ml:notification:m:No route found;3')
               self.set('needRedraw', True)
               print(e)
               traceback.print_exc(file=sys.stdout)
             if "show" in args:
-              """switch to map view and go to start/destination, if requested"""
+              # switch to map view and go to start/destination, if requested
               where = args['show']
               if where == 'start':
                 (cLat, cLon) = (fromLat, fromLon)
@@ -396,8 +396,9 @@ class Route(RanaModule):
         self.set('destinationAddress', posString) # also store in the persistent dictionary
 
     elif message == 'reroute':
-      if type == 'ms' and args == "fromPosToDest" and self.selectManyPoints == False: # handmade
-        """reroute from current position to destination"""
+      if messageType == 'ms' and args == "fromPosToDest" and self.selectManyPoints == False: # handmade
+        # reroute from current position to destination
+
         # is there a destination and valid position ?
         print("route: rerouting from current position to last destination")
         pos = self.get('pos', None)
@@ -407,7 +408,7 @@ class Route(RanaModule):
           self.doRoute(pLat, pLon, dLat, dLon)
           self.start = None
 
-    elif type == 'ms' and message == 'addressRouteMenu':
+    elif messageType == 'ms' and message == 'addressRouteMenu':
       if args == 'swap':
         # get current values
         start = self.get('startAddress', None)
@@ -418,7 +419,7 @@ class Route(RanaModule):
         # redraw the screen to show the change
         self.set('needRedraw', True)
 
-    elif type == "ms" and message == "setOSDState":
+    elif messageType == "ms" and message == "setOSDState":
       self.osdMenuState = int(args)
       self.set('needRedraw', True) # show the new menu
 
@@ -500,7 +501,9 @@ class Route(RanaModule):
           self.monav = monav_support.Monav(self.modrana.paths.getMonavServerBinaryPath())
           self.monav.startServer()
         result = self.monav.monavDirections(monavDataFolder, waypoints)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print('route: Monav route lookup failed')
         print(e)
         traceback.print_exc(file=sys.stdout) # find what went wrong
@@ -529,7 +532,9 @@ class Route(RanaModule):
       dataPacks = os.listdir(mainMonavFolder)
       dataPacks = filter(lambda x: os.path.isdir(os.path.join(mainMonavFolder, x)), dataPacks)
       return sorted(dataPacks)
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print('route: listing the Monav data packs failed')
       print(e)
       return []
@@ -643,8 +648,8 @@ class Route(RanaModule):
     (fromLat, fromLon) = directionsWay.getPointByID(0).getLL()
     (toLat, toLon) = directionsWay.getPointByID(-1).getLL()
 
-    """use coordinates for start dest or use first/last point from the route
-       if start/dest coordinates are unknown (None)"""
+    # use coordinates for start dest or use first/last point from the route
+    # if start/dest coordinates are unknown (None)
     if self.start is None:
       self.start = (fromLat, fromLon)
     if self.destination is None:
@@ -708,7 +713,9 @@ class Route(RanaModule):
           # replace strings according to the csv file
           message = regex.sub(replacement, message, re.UNICODE)
         step.setSSMLMessage(message)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("route: error during direction filtering")
         print(e)
         step.setSSMLMessage(message)
@@ -736,15 +743,17 @@ class Route(RanaModule):
           if unicodeName.find('CYRILLIC') != -1:
             cyrillicCharFound = True
             break
-        except Exception, e:
-          """just skip this as the character is  most probably unknown"""
+        except Exception:
+          import sys
+          e = sys.exc_info()[1]
+          # just skip this as the character is  most probably unknown
           pass
       if cyrillicCharFound: # the substring contains at least one cyrillic character
         if cyrillicStringTemp: # append to the already "open" cyrillic string
           cyrillicStringTemp += ' ' + substring
         else: # create a new cyrillic string
-          """make espeak say this word in russian (or other voiceCode),
-          based on Cyrillic being detected in it"""
+          # make espeak say this word in russian (or other voiceCode),
+          # based on Cyrillic being detected in it
           cyrillicStringTemp = '<p xml:lang="%s">%s' % (voiceCode, substring)
 
       else: # no cyrillic found in this substring
