@@ -87,7 +87,7 @@ class Tracklog(RanaModule):
     # eq, due to modRana or device crashing
     self._rescueLogs()
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     if message == "startLogging":
       print("tracklog: starting to log")
       # start a new log
@@ -139,7 +139,7 @@ class Tracklog(RanaModule):
     if key == 'logNameEntry':
       self.set('logNameEntry', result)
 
-  def initLog(self,type='gpx',name=None):
+  def initLog(self, logType='gpx',name=None):
     """start a new log, zero the appropriate variables, etc."""
     self.loggingStartTimestamp = int(time.time())
     self.maxSpeed = 0
@@ -156,9 +156,9 @@ class Tracklog(RanaModule):
 
     self.logName = name
 
-    if type=='gpx':
-      """ importing the GPX module can be time consuming so import it
-      when it is really needed"""
+    if logType=='gpx':
+      # importing the GPX module can be time consuming so import it
+      # when it is really needed
       from upoints import gpx
       self.currentLogGPX = gpx.Trackpoints()
       # set tracklog metadata
@@ -272,12 +272,16 @@ class Tracklog(RanaModule):
     """save current log increment to storage"""
     try:
       self.log1.flush()
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print('tracklog: saving primary temporary log failed')
       print(e)
     try:
       self.log2.flush()
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print('tracklog: saving secondary temporary log failed')
       print(e)
 
@@ -493,15 +497,10 @@ class Tracklog(RanaModule):
         self.initToolsMenu()
         self.toolsMenuDone = True
 
-
-
       parentAction = 'set:menu:main'
-
-      """this is a a list of button parameters, all buttons can be toggleable
-      it is in this form:
-      [list of string-lists for toggling, index of string-list to show]
-      """
-
+      # this is a a list of button parameters, all buttons can be toggleable
+      # it is in this form:
+      # [list of string-lists for toggling, index of string-list to show]
       units = self.m.get('units', None)
 
       # main status text
@@ -587,14 +586,10 @@ class Tracklog(RanaModule):
     if proj and self.pxpyIndex:
       cr.set_source_color(gtk.gdk.color_parse(self.traceColor))
       cr.set_line_width(10)
-
-      """
-      log trace drawing algorithm
-      adapted from TangoGPS source (tracks.c)
-      works surprisingly good :)
-      TODO: use the modulo method for drawing stored tracklogs
-      """
-
+      # log trace drawing algorithm
+      # adapted from TangoGPS source (tracks.c)
+      # works surprisingly good :)
+      # TODO: use the modulo method for drawing stored tracklogs
       posXY = proj.getCurrentPosXY()
       if posXY and self.loggingEnabled and not self.loggingPaused:
         cr.move_to(*posXY) # start drawing from current position
@@ -678,7 +673,11 @@ class Tracklog(RanaModule):
             os.remove(secondaryPath)
             print('tracklog: temporary file %s deleted' % secondaryPath)
 
-        except Exception, e:
+        except Exception:
+
+          import sys
+
+          e = sys.exc_info()[1]
           print('tracklog: exporting unsaved primary log file failed')
           print(e)
           failedPath = "%s_1.csv" % os.path.splitext(logPath)[0]
@@ -686,8 +685,10 @@ class Tracklog(RanaModule):
           try:
             shutil.move(logPath, failedPath)
             print("tracklog: renaming successful")
-          except Exception, e:
-            ('tracklog: renaming %s to %s failed' % (logPath, failedPath))
+          except Exception:
+            import sys
+            e = sys.exc_info()[1]
+            print('tracklog: renaming %s to %s failed' % (logPath, failedPath))
             print(e)
 
 
@@ -720,15 +721,21 @@ class Tracklog(RanaModule):
           os.remove(logPath)
           print('tracklog: temporary file %s deleted' % logPath)
 
-        except Exception, e:
+        except Exception:
+
+          import sys
+
+          e = sys.exc_info()[1]
           print('tracklog: exporting unsaved secondary log file failed')
           failedPath = "%s_2.csv" % os.path.splitext(logPath)[0]
           print('tracklog: renaming to %s instead' % failedPath)
           try:
             shutil.move(logPath, failedPath)
             print("tracklog: renaming successful")
-          except Exception, e:
-            ('tracklog: renaming %s to %s failed' % (logPath, failedPath))
+          except Exception:
+            import sys
+            e = sys.exc_info()[1]
+            print('tracklog: renaming %s to %s failed' % (logPath, failedPath))
             print(e)
     
   def shutdown(self):
